@@ -45,7 +45,6 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
 namespace spec {
 
 using namespace bsoncxx;
@@ -117,20 +116,15 @@ bool should_skip_spec_test(const client& client, document::view test) {
         return true;
     }
 
-    std::string server_version;
-    try {
-        server_version = test_util::get_server_version(client);
-    } catch (const operation_exception& e) {
-        // Mongohouse does not support serverStatus, so if we get an error from
-        // serverStatus, exit this logic early and run the test.
-        std::string message = e.what();
-        if (message.find("command serverStatus is unsupported") != std::string::npos) {
-            return false;
-        }
-
-        throw e;
+    auto run_mongohouse_tests = std::getenv("RUN_MONGOHOUSE_TESTS");
+    if (run_mongohouse_tests && std::string(run_mongohouse_tests) == "ON") {
+        // mongohoused does not return `version` field in response to serverStatus.
+        // Exit early to run the test.
+        return false;
     }
 
+    std::string server_version = test_util::get_server_version(client);
+
     std::string topology = test_util::get_topology(client);
 
     if (test["ignore_if_server_version_greater_than"]) {
@@ -1137,7 +1131,6 @@ void run_crud_tests_in_file(const std::string& test_path, uri test_uri) {
 }
 
 }  // namespace spec
-}  // namespace v_noabi
 }  // namespace mongocxx
 
 #include <mongocxx/config/private/postlude.hh>
